==> rapid_widgets_library-0.2.38.tar.gz: lib/calendar.dart <==
import 'dart:collection';
import 'dart:math';
import 'package:flutter/material.dart';
import 'package:flutter_clean_calendar/flutter_clean_calendar.dart';
import 'package:flutter_clean_calendar/clean_calendar_event.dart';
import 'modify_event.dart';
import 'new_event.dart';
class CalendarEvent extends StatefulWidget {
  const CalendarEvent({Key key}) : super(key: key);
  @override
  _CalendarEventState createState() => _CalendarEventState();
}

class _CalendarEventState extends State<CalendarEvent> {
  DateTime _dateTime = DateTime(DateTime.now().year, DateTime.now().month, DateTime.now().day);
  final Map<DateTime, List<CleanCalendarEvent>> _events =   new HashMap();
  bool copmleted_val = false;
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _handleNewDate(DateTime(DateTime.now().year, DateTime.now().month, DateTime.now().day));
  }
  TextEditingController controller = new TextEditingController();
  TimeOfDay time = TimeOfDay(hour: 0, minute: 0);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Calendar(
        onRangeSelected: (range) =>
            print('Range is ${range.from}, ${range.to}'),
        onMonthChanged: (DateTime dateTime){
        },
        onDateSelected:(DateTime dateTime){
          setState(() {
            _dateTime =dateTime;
          });
          showDialog(
              context: context,
              builder: (context) => NewEventAlert(
                dateTime: dateTime,
                event_val: (String val1,String val2,TimeOfDay startTime,TimeOfDay endTime){
                  setState(() {
                    if(_events.containsKey(dateTime)){
                      List<CleanCalendarEvent>ce =[];
                      ce= _events[dateTime];
                      ce.add(CleanCalendarEvent(val1.toString(),
                          description: val2.toString(),
                          location: getRandomString(5),
                          startTime: DateTime(DateTime.now().year, DateTime.now().month,
                              dateTime.day , startTime.hour, startTime.minute),
                          endTime: DateTime(DateTime.now().year, DateTime.now().month,
                              dateTime.day, endTime.hour, endTime.minute),
                          color: Colors.primaries[Random().nextInt(Colors.primaries.length)]));
                      _events[dateTime]= ce;
                    }
                    else{
                      _events.putIfAbsent(dateTime, () =>   [CleanCalendarEvent(val1.toString(),
                          description: val2.toString(),
                          location: getRandomString(5),
                          startTime: DateTime(DateTime.now().year, DateTime.now().month,
                              dateTime.day , startTime.hour, startTime.minute),
                          endTime: DateTime(DateTime.now().year, DateTime.now().month,
                              dateTime.day, endTime.hour, endTime.minute),
                          color: Colors.primaries[Random().nextInt(Colors.primaries.length)])]
                      );
                    }
                  });
                },
              )
          );
        } ,
        onEventSelected: (CleanCalendarEvent cleanCalendarEvent){
          showDialog(context: context, builder:
              (context) => ModifyEvent(
            eventDesc: cleanCalendarEvent.description,
            eventName: cleanCalendarEvent.summary,
            startTime: cleanCalendarEvent.startTime,
            endTime: cleanCalendarEvent.endTime,
            copm_val: cleanCalendarEvent.isDone,
            event_val: (String val1,String val2,TimeOfDay startTime,TimeOfDay endTime,bool completed,String callBack){
              if(callBack == 'Yes'){
                List<CleanCalendarEvent>ce =[];
                ce = _events[_dateTime];
                print(ce.toString());
                for(int i= 0;i<ce.length;i++){
                  if(ce[i].location == cleanCalendarEvent.location ){
                    setState(() {
                      if(completed){
                        copmleted_val =completed;
                      }

                      print('ce[i].location '+ce[i].location);
                      print('cleanCalendarEvent.location '+cleanCalendarEvent.location );

                      ce[i] =  CleanCalendarEvent(val1,
                          description: val2,
                          isDone: completed,
                          location: cleanCalendarEvent.location,
                          startTime: DateTime(DateTime.now().year, DateTime.now().month,
                              _dateTime.day ,startTime.hour,startTime.minute),
                          endTime: DateTime(DateTime.now().year, DateTime.now().month,
                              _dateTime.day ,endTime.hour,endTime.minute),
                          color: ce[i].color
                      );
                    });
                  }
                }
              }
              else if (callBack =='Delete'){
                print('fgxfg');
                List<CleanCalendarEvent>ce =[];
                ce = _events[_dateTime];
                for(int i= 0;i<ce.length;i++){
                  if(ce[i].summary==val1){
                    setState(() {

                      ce.removeAt(i);
                    });
                  }
                }

              }
            },
          )
          );

        },
        startOnMonday: true,
        weekDays: ['Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa', 'Su'],
        events: _events,
        isExpandable: true,
        eventDoneColor: Colors.green,
        selectedColor: Colors.pink,
        todayColor: Colors.blue,
        eventColor: Colors.grey,
        locale: 'en_IN',
        todayButtonText: 'Today',
        isExpanded: true,
        expandableDateFormat: 'EEEE, dd. MMMM yyyy',
        dayOfWeekStyle: TextStyle(
            color: Colors.black, fontWeight: FontWeight.w800, fontSize: 11),
      ),
    );
  }
  void _handleNewDate(date) {
    print('Date selected: $date');
  }
  static const _chars = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz1234567890';
  Random _rnd = Random();
  String getRandomString(int length) => String.fromCharCodes(Iterable.generate(
      length, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));
}

==> rapid_widgets_library-0.2.46.tar.gz: lib/calendar.dart <==
import 'dart:collection';
import 'dart:math';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

import 'package:flutter_clean_calendar/flutter_clean_calendar.dart';
import 'package:flutter_clean_calendar/clean_calendar_event.dart';

import 'modify_event.dart';
import 'new_event.dart';
class CalendarEvent extends StatefulWidget {
  const CalendarEvent({Key key}) : super(key: key);
  @override
  _CalendarEventState createState() => _CalendarEventState();
}

class _CalendarEventState extends State<CalendarEvent> {
  DateTime _dateTime = DateTime(DateTime.now().year, DateTime.now().month, DateTime.now().day);
  final Map<DateTime, List<CleanCalendarEvent>> _events =   new HashMap();
  bool copmleted_val = false;
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    _handleNewDate(DateTime(DateTime.now().year, DateTime.now().month, DateTime.now().day));
  }
  TextEditingController controller = new TextEditingController();
  TimeOfDay time = TimeOfDay(hour: 0, minute: 0);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Calendar(
        onRangeSelected: (range) =>
            print('Range is ${range.from}, ${range.to}'),
        onMonthChanged: (DateTime dateTime){
        },
        onDateSelected:(DateTime dateTime){
          setState(() {
            _dateTime =dateTime;
          });
          showDialog(
              context: context,
              builder: (context) => NewEventAlert(
                dateTime: dateTime,
                event_val: (String val1,String val2,TimeOfDay startTime,TimeOfDay endTime){
                  setState(() {
                    if(_events.containsKey(dateTime)){
                      List<CleanCalendarEvent>ce =[];
                      ce= _events[dateTime];
                      ce.add(CleanCalendarEvent(val1.toString(),
                          description: val2.toString(),
                          location: getRandomString(5),
                          startTime: DateTime(DateTime.now().year, DateTime.now().month,
                              dateTime.day , startTime.hour, startTime.minute),
                          endTime: DateTime(DateTime.now().year, DateTime.now().month,
                              dateTime.day, endTime.hour, endTime.minute),
                          color: Colors.primaries[Random().nextInt(Colors.primaries.length)]));
                      _events[dateTime]= ce;
                    }
                    else{
                      _events.putIfAbsent(dateTime, () =>   [CleanCalendarEvent(val1.toString(),
                          description: val2.toString(),
                          location: getRandomString(5),
                          startTime: DateTime(DateTime.now().year, DateTime.now().month,
                              dateTime.day , startTime.hour, startTime.minute),
                          endTime: DateTime(DateTime.now().year, DateTime.now().month,
                              dateTime.day, endTime.hour, endTime.minute),
                          color: Colors.primaries[Random().nextInt(Colors.primaries.length)])]
                      );
                    }
                  });
                },
              )
          );
        } ,
        onEventSelected: (CleanCalendarEvent cleanCalendarEvent){
          showDialog(context: context, builder:
              (context) => ModifyEvent(
            eventDesc: cleanCalendarEvent.description,
            eventName: cleanCalendarEvent.summary,
            startTime: cleanCalendarEvent.startTime,
            endTime: cleanCalendarEvent.endTime,
            copm_val: cleanCalendarEvent.isDone,
            event_val: (String val1,String val2,TimeOfDay startTime,TimeOfDay endTime,bool completed,String callBack){
              if(callBack == 'Yes'){
                List<CleanCalendarEvent>ce =[];
                ce = _events[_dateTime];
                print(ce.toString());
                for(int i= 0;i<ce.length;i++){
                  if(ce[i].location == cleanCalendarEvent.location ){
                    setState(() {
                      if(completed){
                        copmleted_val =completed;
                      }

                      print('ce[i].location '+ce[i].location);
                      print('cleanCalendarEvent.location '+cleanCalendarEvent.location );

                      ce[i] =  CleanCalendarEvent(val1,
                          description: val2,
                          isDone: completed,
                          location: cleanCalendarEvent.location,
                          startTime: DateTime(DateTime.now().year, DateTime.now().month,
                              _dateTime.day ,startTime.hour,startTime.minute),
                          endTime: DateTime(DateTime.now().year, DateTime.now().month,
                              _dateTime.day ,endTime.hour,endTime.minute),
                          color: ce[i].color
                      );
                    });
                  }
                }
              }
              else if (callBack =='Delete'){
                print('fgxfg');
                List<CleanCalendarEvent>ce =[];
                ce = _events[_dateTime];
                for(int i= 0;i<ce.length;i++){
                  if(ce[i].summary==val1){
                    setState(() {

                      ce.removeAt(i);
                    });
                  }
                }

              }
            },
          )
          );

        },
        startOnMonday: true,
        weekDays: ['Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa', 'Su'],
        events: _events,
        isExpandable: true,
        eventDoneColor: Colors.green,
        selectedColor: Colors.pink,
        todayColor: Colors.blue,
        eventColor: Colors.grey,
        locale: 'en_IN',
        todayButtonText: 'Today',
        isExpanded: true,
        expandableDateFormat: 'EEEE, dd. MMMM yyyy',
        dayOfWeekStyle: GoogleFonts.getFont('Roboto',
            color: Colors.black, fontWeight: FontWeight.w800, fontSize: 11),
      ),
    );
  }
  void _handleNewDate(date) {
    print('Date selected: $date');
  }
  static const _chars = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz1234567890';
  Random _rnd = Random();
  String getRandomString(int length) => String.fromCharCodes(Iterable.generate(
      length, (_) => _chars.codeUnitAt(_rnd.nextInt(_chars.length))));
}
